@@ -298,6 +298,8 @@ def test_returns() -> None:
         """
     )
     assert docstring.returns is None
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 0
 
     docstring = parse(
         """
@@ -309,6 +311,9 @@ def test_returns() -> None:
     assert docstring.returns.type_name is None
     assert docstring.returns.description == "description"
     assert not docstring.returns.is_generator
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 1
+    assert docstring.many_returns[0] == docstring.returns
 
     docstring = parse(
         """
@@ -320,6 +325,9 @@ def test_returns() -> None:
     assert docstring.returns.type_name == "int"
     assert docstring.returns.description == "description"
     assert not docstring.returns.is_generator
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 1
+    assert docstring.many_returns[0] == docstring.returns
 
 
 def test_yields() -> None:
@@ -329,6 +337,8 @@ def test_yields() -> None:
         """
     )
     assert docstring.returns is None
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 0
 
     docstring = parse(
         """
@@ -340,6 +350,9 @@ def test_yields() -> None:
     assert docstring.returns.type_name is None
     assert docstring.returns.description == "description"
     assert docstring.returns.is_generator
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 1
+    assert docstring.many_returns[0] == docstring.returns
 
     docstring = parse(
         """
@@ -351,6 +364,9 @@ def test_yields() -> None:
     assert docstring.returns.type_name == "int"
     assert docstring.returns.description == "description"
     assert docstring.returns.is_generator
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 1
+    assert docstring.many_returns[0] == docstring.returns
 
 
 def test_raises() -> None:
